@@ -40,7 +40,7 @@ use self::{
   pods::{KubeContainer, KubePod},
   replicasets::KubeReplicaSet,
   replication_controllers::KubeReplicationController,
-  roles::{KubeClusterRoles, KubeRoles},
+  roles::{KubeClusterRoleBinding, KubeClusterRoles, KubeRoleBindings, KubeRoles},
   secrets::KubeSecret,
   statefulsets::KubeStatefulSet,
   storageclass::KubeStorageClass,
@@ -75,7 +75,9 @@ pub enum ActiveBlock {
   RplCtrl,
   StorageClasses,
   Roles,
+  RoleBindings,
   ClusterRoles,
+  ClusterRoleBinding,
   More,
 }
 
@@ -132,7 +134,9 @@ pub struct Data {
   pub rpl_ctrls: StatefulTable<KubeReplicationController>,
   pub storage_classes: StatefulTable<KubeStorageClass>,
   pub roles: StatefulTable<KubeRoles>,
-  pub clusterroles: StatefulTable<KubeClusterRoles>,
+  pub role_bindings: StatefulTable<KubeRoleBindings>,
+  pub cluster_roles: StatefulTable<KubeClusterRoles>,
+  pub cluster_role_binding: StatefulTable<KubeClusterRoleBinding>,
 }
 
 /// selected data items
@@ -207,7 +211,9 @@ impl Default for Data {
       rpl_ctrls: StatefulTable::new(),
       storage_classes: StatefulTable::new(),
       roles: StatefulTable::new(),
-      clusterroles: StatefulTable::new(),
+      role_bindings: StatefulTable::new(),
+      cluster_roles: StatefulTable::new(),
+      cluster_role_binding: StatefulTable::new(),
     }
   }
 }
@@ -333,9 +339,12 @@ impl Default for App {
         // ("Persistent Volumes".into(), ActiveBlock::RplCtrl),
         ("Storage Classes".into(), ActiveBlock::StorageClasses),
         ("Roles".into(), ActiveBlock::Roles),
-        // ("Role Bindings".into(), ActiveBlock::RplCtrl),
+        ("Role Bindings".into(), ActiveBlock::RoleBindings),
         ("Cluster Roles".into(), ActiveBlock::ClusterRoles),
-        // ("Cluster Role Bindings".into(), ActiveBlock::RplCtrl),
+        (
+          "Cluster Role Bindings".into(),
+          ActiveBlock::ClusterRoleBinding,
+        ),
         // ("Service Accounts".into(), ActiveBlock::RplCtrl),
         // ("Ingresses".into(), ActiveBlock::RplCtrl),
         // ("Network Policies".into(), ActiveBlock::RplCtrl),
@@ -530,7 +539,9 @@ impl App {
     self.dispatch(IoEvent::GetReplicationControllers).await;
     self.dispatch(IoEvent::GetStorageClasses).await;
     self.dispatch(IoEvent::GetRoles).await;
+    self.dispatch(IoEvent::GetRoleBindings).await;
     self.dispatch(IoEvent::GetClusterRoles).await;
+    self.dispatch(IoEvent::GetClusterRoleBinding).await;
     self.dispatch(IoEvent::GetMetrics).await;
   }
 
@@ -575,9 +586,15 @@ impl App {
       ActiveBlock::Roles => {
         self.dispatch(IoEvent::GetRoles).await;
       }
+      ActiveBlock::RoleBindings => {
+        self.dispatch(IoEvent::GetRoleBindings).await;
+      }
       ActiveBlock::ClusterRoles => {
         self.dispatch(IoEvent::GetClusterRoles).await;
       }
+      ActiveBlock::ClusterRoleBinding => {
+        self.dispatch(IoEvent::GetClusterRoleBinding).await;
+      }
       ActiveBlock::Logs => {
         if !self.is_streaming {
           // do not tail to avoid duplicates
@@ -675,7 +692,7 @@ mod test_utils {
       .expect("Something went wrong reading yaml file");
     assert_ne!(yaml, "".to_string());
 
-    let res_list: serde_yaml::Result<ObjectList<K>> = serde_yaml::from_str(&*yaml);
+    let res_list: serde_yaml::Result<ObjectList<K>> = serde_yaml::from_str(&yaml);
     assert!(res_list.is_ok(), "{:?}", res_list.err());
     res_list.unwrap()
   }
@@ -736,7 +753,12 @@ mod tests {
     );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetStorageClasses);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetRoles);
+    assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetRoleBindings);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetClusterRoles);
+    assert_eq!(
+      sync_io_rx.recv().await.unwrap(),
+      IoEvent::GetClusterRoleBinding
+    );
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetMetrics);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNamespaces);
     assert_eq!(sync_io_rx.recv().await.unwrap(), IoEvent::GetNodes);
