@@ -2,11 +2,11 @@ use crossterm::event::{MouseEvent, MouseEventKind};
 use kubectl_view_allocations::GroupBy;
 use serde::Serialize;
 
-use crate::app::secrets::KubeSecret;
 use crate::{
   app::{
     key_binding::DEFAULT_KEYBINDING,
     models::{KubeResource, Scrollable, ScrollableTxt, StatefulTable},
+    secrets::KubeSecret,
     ActiveBlock, App, Route, RouteId,
   },
   cmd::IoCmdEvent,
@@ -475,8 +475,23 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
+        ActiveBlock::RoleBindings => {
+          if let Some(res) = handle_block_action(key, &mut app.data.role_bindings) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "rolebindings".to_owned(),
+                value: res.name.to_owned(),
+                ns: Some(res.namespace.to_owned()),
+              },
+            )
+            .await;
+          }
+        }
         ActiveBlock::ClusterRoles => {
-          if let Some(res) = handle_block_action(key, &mut app.data.clusterroles) {
+          if let Some(res) = handle_block_action(key, &mut app.data.cluster_roles) {
             let _ok = handle_describe_decode_or_yaml_action(
               key,
               app,
@@ -490,6 +505,21 @@ async fn handle_route_events(key: Key, app: &mut App) {
             .await;
           }
         }
+        ActiveBlock::ClusterRoleBinding => {
+          if let Some(res) = handle_block_action(key, &mut app.data.cluster_role_binding) {
+            let _ok = handle_describe_decode_or_yaml_action(
+              key,
+              app,
+              &res,
+              IoCmdEvent::GetDescribe {
+                kind: "clusterrolebinding".to_owned(),
+                value: res.name.to_owned(),
+                ns: None,
+              },
+            )
+            .await;
+          }
+        }
         ActiveBlock::Contexts | ActiveBlock::Utilization | ActiveBlock::Help => { /* Do nothing */ }
       }
     }
@@ -554,7 +584,9 @@ async fn handle_block_scroll(app: &mut App, up: bool, is_mouse: bool, page: bool
     ActiveBlock::RplCtrl => app.data.rpl_ctrls.handle_scroll(up, page),
     ActiveBlock::StorageClasses => app.data.storage_classes.handle_scroll(up, page),
     ActiveBlock::Roles => app.data.roles.handle_scroll(up, page),
-    ActiveBlock::ClusterRoles => app.data.clusterroles.handle_scroll(up, page),
+    ActiveBlock::RoleBindings => app.data.role_bindings.handle_scroll(up, page),
+    ActiveBlock::ClusterRoles => app.data.cluster_roles.handle_scroll(up, page),
+    ActiveBlock::ClusterRoleBinding => app.data.cluster_role_binding.handle_scroll(up, page),
     ActiveBlock::Contexts => app.data.contexts.handle_scroll(up, page),
     ActiveBlock::Utilization => app.data.metrics.handle_scroll(up, page),
     ActiveBlock::Help => app.help_docs.handle_scroll(up, page),
@@ -596,9 +628,10 @@ fn inverse_dir(up: bool, is_mouse: bool) -> bool {
 
 #[cfg(test)]
 mod tests {
+  use k8s_openapi::ByteString;
+
   use super::*;
   use crate::app::{contexts::KubeContext, pods::KubePod};
-  use k8s_openapi::ByteString;
 
   #[test]
   fn test_inverse_dir() {
