@@ -28,7 +28,7 @@ use crate::app::{
   pods::KubePod,
   replicasets::KubeReplicaSet,
   replication_controllers::KubeReplicationController,
-  roles::{KubeClusterRoles, KubeRoles},
+  roles::{KubeClusterRoleBinding, KubeClusterRoles, KubeRoleBindings, KubeRoles},
   secrets::KubeSecret,
   statefulsets::KubeStatefulSet,
   storageclass::KubeStorageClass,
@@ -318,13 +318,31 @@ impl<'a> Network<'a> {
     app.data.roles.set_items(items);
   }
 
+  pub async fn get_role_bindings(&self) {
+    let items: Vec<KubeRoleBindings> = self
+      .get_namespaced_resources(|it| KubeRoleBindings::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.role_bindings.set_items(items);
+  }
+
   pub async fn get_cluster_roles(&self) {
     let items: Vec<KubeClusterRoles> = self
       .get_namespaced_resources(|it| KubeClusterRoles::from_api(it))
       .await;
 
     let mut app = self.app.lock().await;
-    app.data.clusterroles.set_items(items);
+    app.data.cluster_roles.set_items(items);
+  }
+
+  pub async fn get_cluster_role_binding(&self) {
+    let items: Vec<KubeClusterRoleBinding> = self
+      .get_namespaced_resources(|it| KubeClusterRoleBinding::from_api(it))
+      .await;
+
+    let mut app = self.app.lock().await;
+    app.data.cluster_role_binding.set_items(items);
   }
 
   /// calls the kubernetes API to list the given resource for either selected namespace or all namespaces
