@@ -29,7 +29,9 @@ pub enum IoEvent {
   GetReplicationControllers,
   GetStorageClasses,
   GetRoles,
+  GetRoleBindings,
   GetClusterRoles,
+  GetClusterRoleBinding,
   GetMetrics,
   RefreshClient,
 }
@@ -163,9 +165,15 @@ impl<'a> Network<'a> {
       IoEvent::GetRoles => {
         self.get_roles().await;
       }
+      IoEvent::GetRoleBindings => {
+        self.get_role_bindings().await;
+      }
       IoEvent::GetClusterRoles => {
         self.get_cluster_roles().await;
       }
+      IoEvent::GetClusterRoleBinding => {
+        self.get_cluster_role_binding().await;
+      }
     };
 
     let mut app = self.app.lock().await;
